@@ -1,3 +1,6 @@
+# SPDX-FileCopyrightText: 2021 ladyada for Adafruit Industries
+# SPDX-License-Identifier: MIT
+
 """
 This example uses addfruit_display_text.label to display text using a custom font
 loaded by adafruit_bitmap_font
@@ -13,8 +16,8 @@ from adafruit_bitmap_font import bitmap_font
 display = board.DISPLAY
 
 # try uncommenting different font files if you like
-font_file = "fonts/Arial-16.bdf"
-# font_file = "fonts/yasashi24.pcf"
+font_file = "fonts/LeagueSpartan-Bold-16.bdf"
+# font_file = "fonts/Junction-regular-24.pcf"
 
 # Set text, font, and color
 text = "HELLO WORLD"
